@@ -1,6 +1,6 @@
 // maingui.h
 
-// Copyright (C) 2012-2017 by Werner Lemberg.
+// Copyright (C) 2012-2018 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -64,8 +64,8 @@ class Main_GUI
 public:
   Main_GUI(bool,
            int, int, int,
-           bool, bool,
-           bool, int,
+           int, int,
+           int, int,
            const char*, int,
            bool, bool, bool,
            bool, bool, bool,
@@ -107,9 +107,9 @@ private:
   int hinting_range_min;
   int hinting_range_max;
   int hinting_limit;
-  int gray_strong_stem_width;
-  int gdi_cleartype_strong_stem_width;
-  int dw_cleartype_strong_stem_width;
+  int gray_stem_width_mode;
+  int gdi_cleartype_stem_width_mode;
+  int dw_cleartype_stem_width_mode;
   int increase_x_height;
   QString x_height_snapping_exceptions_string;
   number_range* x_height_snapping_exceptions;
@@ -203,9 +203,13 @@ private:
   QSpinBox* max_box;
 
   QLabel* stem_label;
-  QCheckBox* gray_box;
-  QCheckBox* gdi_box;
-  QCheckBox* dw_box;
+
+  QLabel* gray_label;
+  QComboBox* gray_box;
+  QLabel* gdi_label;
+  QComboBox* gdi_box;
+  QLabel* dw_label;
+  QComboBox* dw_box;
 
   QLabel* default_label;
   QComboBox* default_box;
