@@ -1,7 +1,7 @@
 /* numberset.c */
 
 /*
- * Copyright (C) 2012-2017 by Werner Lemberg.
+ * Copyright (C) 2012-2018 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -32,13 +32,22 @@ number_set_new(int start,
                int max)
 {
   number_range* nr;
+  int tmp;
 
 
+  if (min < 0)
+    min = 0;
+  if (max < 0)
+    max = INT_MAX;
+  if (min > max)
+  {
+    tmp = min;
+    min = max;
+    max = tmp;
+  }
+
   if (start > end)
   {
-    int tmp;
-
-
     tmp = start;
     start = end;
     end = tmp;
@@ -53,6 +62,80 @@ number_set_new(int start,
 
   nr->start = start;
   nr->end = end;
+  nr->base = 0;
+  nr->wrap = 0;
+  nr->next = NULL;
+
+  return nr;
+}
+
+
+int
+wrap_range_check_wraps(size_t num_wraps,
+                       int* wraps)
+{
+  size_t i;
+
+
+  /* `wraps' must have at least two elements */
+  if (!wraps || num_wraps < 2)
+    return 1;
+
+  /* first `wraps' element must be larger than or equal to -1 */
+  if (wraps[0] < -1)
+    return 1;
+
+  /* check that all elements of `wraps' are strictly ascending */
+  for (i = 1; i < num_wraps; i++)
+    if (wraps[i] <= wraps[i - 1])
+      return 1;
+
+  return 0;
+}
+
+
+number_range*
+wrap_range_new(int start,
+               int end,
+               size_t num_wraps,
+               int* wraps)
+{
+  number_range* nr;
+  size_t i;
+  int s, e;
+
+
+  if (num_wraps < 2)
+    return NUMBERSET_INVALID_WRAP_RANGE;
+
+  if (start > end)
+  {
+    s = end;
+    e = start;
+  }
+  else
+  {
+    s = start;
+    e = end;
+  }
+
+  /* search fitting interval in `wraps' */
+  for (i = 1; i < num_wraps; i++)
+  {
+    if (s > wraps[i - 1] && e <= wraps[i])
+      break;
+  }
+  if (i == num_wraps)
+    return NUMBERSET_INVALID_WRAP_RANGE;
+
+  nr = (number_range*)malloc(sizeof (number_range));
+  if (!nr)
+    return NUMBERSET_ALLOCATION_ERROR;
+
+  nr->start = start;
+  nr->end = end;
+  nr->base = wraps[i - 1] + 1;
+  nr->wrap = wraps[i];
   nr->next = NULL;
 
   return nr;
@@ -69,6 +152,10 @@ number_set_prepend(number_range* list,
   if (!list)
     return element;
 
+  /* `list' and `element' must both be normal integer ranges */
+  if (list->base != list->wrap || element->base != element->wrap)
+    return NUMBERSET_INVALID_RANGE;
+
   if (element->start <= list->end)
   {
     if (element->end < list->start)
@@ -93,6 +180,87 @@ number_set_prepend(number_range* list,
 }
 
 
+number_range*
+number_set_prepend_unsorted(number_range* list,
+                            number_range* element)
+{
+  if (!element)
+    return list;
+
+  if (!list)
+    return element;
+
+  /* `list' and `element' must both be normal integer ranges */
+  if (list->base != list->wrap || element->base != element->wrap)
+    return NUMBERSET_INVALID_RANGE;
+
+  element->next = list;
+
+  return element;
+}
+
+
+number_range*
+wrap_range_prepend(number_range* list,
+                   number_range* element)
+{
+  if (!element)
+    return list;
+
+  if (!list)
+    return element;
+
+  /* `list' and `element' must both be wrap-around ranges */
+  if (list->base == list->wrap || element->base == element->wrap)
+    return NUMBERSET_INVALID_RANGE;
+
+  /* we explicitly assume that the [base;wrap] intervals */
+  /* of `list' and `element' either don't overlap ... */
+  if (element->base < list->base)
+    return NUMBERSET_NOT_ASCENDING;
+  if (element->base > list->base)
+    goto prepend;
+
+  /* ... or are exactly the same; */
+  /* in this case, we can't append if the list's range really wraps around */
+  if (list->start > list->end)
+    return NUMBERSET_OVERLAPPING_RANGES;
+
+  if (element->start <= list->end)
+  {
+    if (element->end < list->start)
+      return NUMBERSET_NOT_ASCENDING;
+    else
+      return NUMBERSET_OVERLAPPING_RANGES;
+  }
+
+  if (element->start > element->end)
+  {
+    number_range* nr = list->next;
+
+
+    /* we must search backwards to check */
+    /* whether the wrapped part of the range overlaps */
+    /* with an already existing range */
+    /* (in the same [base;wrap] interval) */
+    while (nr)
+    {
+      if (element->base != nr->base)
+        break;
+      if (element->end > nr->start)
+        return NUMBERSET_OVERLAPPING_RANGES;
+
+      nr = nr->next;
+    }
+  }
+
+prepend:
+  element->next = list;
+
+  return element;
+}
+
+
 number_range*
 number_set_insert(number_range* list,
                   number_range* element)
@@ -107,6 +275,10 @@ number_set_insert(number_range* list,
   if (!list)
     return element;
 
+  /* `list' and `element' must both be normal integer ranges */
+  if (list->base != list->wrap || element->base != element->wrap)
+    return NUMBERSET_INVALID_RANGE;
+
   prev = NULL;
   while (nr)
   {
@@ -115,26 +287,35 @@ number_set_insert(number_range* list,
       return NUMBERSET_OVERLAPPING_RANGES;
 
     /* merge adjacent ranges */
-    if (element->start == nr->end + 1)
-    {
-      nr->end = element->end;
-
-      free(element);
-
-      return list;
-    }
     if (element->end + 1 == nr->start)
     {
       nr->start = element->start;
 
       free(element);
 
+      if (nr->next
+          && nr->next->end + 1 == nr->start)
+      {
+        element = nr->next;
+        element->end = nr->end;
+        free(nr);
+        return element;
+      }
+
       return list;
     }
 
     /* insert element */
     if (element->start > nr->end)
     {
+      /* merge adjacent ranges */
+      if (nr->end + 1 == element->start)
+      {
+        nr->end = element->end;
+        free(element);
+        return list;
+      }
+
       if (prev)
         prev->next = element;
       element->next = nr;
@@ -146,7 +327,7 @@ number_set_insert(number_range* list,
     nr = nr->next;
   }
 
-  /* append element */
+  /* prepend element */
   prev->next = element;
   element->next = NULL;
 
@@ -155,43 +336,73 @@ number_set_insert(number_range* list,
 
 
 number_range*
-number_set_normalize(number_range* list)
+wrap_range_insert(number_range* list,
+                  number_range* element)
 {
-  number_range* cur;
+  number_range* nr = list;
   number_range* prev;
 
 
+  if (!element)
+    return list;
+
   if (!list)
-    return NULL;
+    return element;
 
-  prev = list;
-  cur = list->next;
+  /* `list' and `element' must both be wrap-around ranges */
+  if (list->base == list->wrap || element->base == element->wrap)
+    return NUMBERSET_INVALID_RANGE;
 
-  if (!cur)
-    return list; /* only a single element, nothing to do */
-
-  while (cur)
+  prev = NULL;
+  while (nr)
   {
-    if (prev->end + 1 == cur->start)
+    /* we explicitly assume that the [base;wrap] intervals */
+    /* of `list' and `element' either don't overlap ... */
+    if (element->base < nr->base)
+      goto next;
+    if (element->base > nr->base)
+      goto insert;
+
+    /* ... or are exactly the same */
+
+    if (nr->start > nr->end)
     {
-      number_range* tmp;
+      /* range really wraps around */
+      if (element->start > element->end)
+        return NUMBERSET_OVERLAPPING_RANGES;
 
-
-      prev->end = cur->end;
-
-      tmp = cur;
-      cur = cur->next;
-      prev->next = cur;
-
-      free(tmp);
+      if (element->start <= nr->end
+          || element->end >= nr->start)
+        return NUMBERSET_OVERLAPPING_RANGES;
     }
     else
     {
-      prev = cur;
-      cur = cur->next;
+      /* normal range */
+      if (element->start <= nr->end
+          && element->end >= nr->start)
+        return NUMBERSET_OVERLAPPING_RANGES;
+
+      /* insert element */
+      if (element->start > nr->end)
+      {
+      insert:
+        if (prev)
+          prev->next = element;
+        element->next = nr;
+
+        return prev ? list : element;
+      }
     }
+
+  next:
+    prev = nr;
+    nr = nr->next;
   }
 
+  /* prepend element */
+  prev->next = element;
+  element->next = NULL;
+
   return list;
 }
 
@@ -378,6 +589,8 @@ number_set_parse(const char* s,
         /* prepend new range to list */
         new_range->start = n;
         new_range->end = m;
+        new_range->base = 0;
+        new_range->wrap = 0;
         new_range->next = cur;
         cur = new_range;
       }
@@ -399,7 +612,7 @@ number_set_parse(const char* s,
   {
     /* success */
     if (number_set)
-      *number_set = number_set_normalize(number_set_reverse(cur));
+      *number_set = number_set_reverse(cur);
   }
 
   return s;
@@ -438,18 +651,27 @@ number_set_show(number_range* number_set,
   const char* comma;
 
 
-  if (min < 0)
-    min = 0;
-  if (max < 0)
-    max = INT_MAX;
-  if (min > max)
+  if (nr && nr->base == nr->wrap)
   {
-    int t;
+    if (min < 0)
+      min = 0;
+    if (max < 0)
+      max = INT_MAX;
+    if (min > max)
+    {
+      int t;
 
 
-    t = min;
-    min = max;
-    max = t;
+      t = min;
+      min = max;
+      max = t;
+    }
+  }
+  else
+  {
+    /* `min' and `max' are meaningless for wrap-around ranges */
+    min = INT_MIN;
+    max = INT_MAX;
   }
 
   s = sdsempty();
@@ -505,11 +727,25 @@ number_set_is_element(number_range* number_set,
 
   while (nr)
   {
-    if (number < nr->start)
-      return 0;
-    if (nr->start <= number
-        && number <= nr->end)
-      return 1;
+    if (nr->start > nr->end)
+    {
+      if (number < nr->base)
+        return 0;
+      if (number <= nr->end)
+        return 1;
+      if ( number < nr->start)
+        return 0;
+      if (number <= nr->wrap)
+        return 1;
+    }
+    else
+    {
+      if (number < nr->start)
+        return 0;
+      if (number <= nr->end)
+        return 1;
+    }
+
     nr = nr->next;
   }
 
@@ -521,7 +757,7 @@ int
 number_set_get_first(number_set_iter* iter_p)
 {
   if (!iter_p || !iter_p->range)
-    return 0;
+    return -1;
 
   iter_p->val = iter_p->range->start;
 
@@ -533,16 +769,37 @@ int
 number_set_get_next(number_set_iter* iter_p)
 {
   if (!iter_p || !iter_p->range)
-    return 0;
+    return -1;
 
   iter_p->val++;
 
-  if (iter_p->val > iter_p->range->end)
+  if (iter_p->range->start > iter_p->range->end)
   {
-    iter_p->range = iter_p->range->next;
+    /* range really wraps around */
+    if (iter_p->val > iter_p->range->wrap)
+      iter_p->val = iter_p->range->base;
+    else if (iter_p->val < iter_p->range->start
+             && iter_p->val > iter_p->range->end)
+    {
+      iter_p->range = iter_p->range->next;
 
-    if (iter_p->range)
-      iter_p->val = iter_p->range->start;
+      if (iter_p->range)
+        iter_p->val = iter_p->range->start;
+      else
+        return -1;
+    }
+  }
+  else
+  {
+    if (iter_p->val > iter_p->range->end)
+    {
+      iter_p->range = iter_p->range->next;
+
+      if (iter_p->range)
+        iter_p->val = iter_p->range->start;
+      else
+        return -1;
+    }
   }
 
   return iter_p->val;
