@@ -1,7 +1,7 @@
 /* ta.h */
 
 /*
- * Copyright (C) 2011-2017 by Werner Lemberg.
+ * Copyright (C) 2011-2018 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -346,6 +346,10 @@ FT_Error
 TA_control_file_read(FONT* font,
                      FILE* control_file);
 
+FT_Error
+TA_sfnt_compute_composite_pointsums(SFNT* sfnt,
+                                    FONT* font);
+
 FT_Error
 TA_sfnt_build_glyph_instructions(SFNT* sfnt,
                                  FONT* font,
