@@ -1,7 +1,7 @@
 /* tabytecode.c */
 
 /*
- * Copyright (C) 2011-2017 by Werner Lemberg.
+ * Copyright (C) 2011-2018 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -772,7 +772,7 @@ TA_sfnt_build_delta_exceptions(SFNT* sfnt,
   FT_Bool allocated_after_IUP = 0;
 
 
-  num_points = (unsigned int)font->loader->gloader->base.outline.n_points;
+  num_points = glyph->num_points;
 
   /* loop over all fitting control instructions */
   for (;;)
