@@ -1,7 +1,7 @@
 /* tabytecode.h */
 
 /*
- * Copyright (C) 2011-2017 by Werner Lemberg.
+ * Copyright (C) 2011-2018 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -303,7 +303,9 @@
 
 #define sal_i 0
 #define sal_j sal_i + 1
-#define sal_temp1 sal_j + 1
+#define sal_k sal_j + 1
+#define sal_limit sal_k + 1
+#define sal_temp1 sal_limit + 1
 #define sal_temp2 sal_temp1 + 1
 #define sal_temp3 sal_temp2 + 1
 #define sal_best sal_temp3 + 1
@@ -318,16 +320,37 @@
 #define sal_point_max sal_point_min + 1
 #define sal_base sal_point_max + 1
 #define sal_num_packed_segments sal_base + 1
-#define sal_top_to_bottom_hinting sal_num_packed_segments + 1
+#define sal_num_stem_widths sal_num_packed_segments + 1
+#define sal_stem_width_offset sal_num_stem_widths + 1
+#define sal_have_cached_width sal_stem_width_offset + 1
+#define sal_cached_width_offset sal_have_cached_width + 1
+#define sal_top_to_bottom_hinting sal_cached_width_offset + 1
 #define sal_segment_offset sal_top_to_bottom_hinting + 1 /* must be last */
 
+/*
+ * After the above registers we have the following layout in the storage
+ * area.
+ *
+ *   sal[sal_segment_offset]:
+ *     `2 * num_segments' registers to hold the start and end points of a
+ *     glyph's segments.
+ *   sal[sal_segment_offset + 2*num_segments]:
+ *     quantized stem width 1 (before stem width computing)
+ *     quantized stem width 1 (after stem width computing)
+ *     quantized stem width 2 (before stem width computing)
+ *     quantized stem width 2 (after stem width computing)
+ *     ...
+ */
+
 
 /* bytecode function numbers */
 
 /* 0 */
 #define bci_align_x_height 0
 #define bci_round bci_align_x_height + 1
-#define bci_smooth_stem_width bci_round + 1
+#define bci_natural_stem_width bci_round + 1
+#define bci_quantize_stem_width bci_natural_stem_width + 1
+#define bci_smooth_stem_width bci_quantize_stem_width + 1
 #define bci_get_best_width bci_smooth_stem_width + 1
 #define bci_strong_stem_width bci_get_best_width + 1
 #define bci_loop_do bci_strong_stem_width + 1
@@ -344,11 +367,11 @@
 #define bci_number_set_is_element bci_nibbles + 1
 #define bci_number_set_is_element2 bci_number_set_is_element + 1
 
-/* 18 */
+/* 20 */
 #define bci_create_segment bci_number_set_is_element2 + 1
 #define bci_create_segments bci_create_segment + 1
 
-/* 20 */
+/* 22 */
 /* the next ten entries must stay in this order */
 #define bci_create_segments_0 bci_create_segments + 1
 #define bci_create_segments_1 bci_create_segments_0 + 1
@@ -363,7 +386,7 @@
 
 #define bci_create_segments_composite bci_create_segments_9 + 1
 
-/* 31 */
+/* 33 */
 /* the next ten entries must stay in this order */
 #define bci_create_segments_composite_0 bci_create_segments_composite + 1
 #define bci_create_segments_composite_1 bci_create_segments_composite_0 + 1
@@ -376,31 +399,31 @@
 #define bci_create_segments_composite_8 bci_create_segments_composite_7 + 1
 #define bci_create_segments_composite_9 bci_create_segments_composite_8 + 1
 
-/* 41 */
+/* 43 */
 /* the next three entries must stay in this order */
 #define bci_deltap1 bci_create_segments_composite_9 + 1
 #define bci_deltap2 bci_deltap1 + 1
 #define bci_deltap3 bci_deltap2 + 1
 
-/* 44 */
+/* 46 */
 #define bci_align_point bci_deltap3 + 1
 #define bci_align_segment bci_align_point + 1
 #define bci_align_segments bci_align_segment + 1
 
-/* 47 */
+/* 49 */
 #define bci_scale_contour bci_align_segments + 1
 #define bci_scale_glyph bci_scale_contour + 1
 #define bci_scale_composite_glyph bci_scale_glyph + 1
 #define bci_shift_contour bci_scale_composite_glyph + 1
 #define bci_shift_subglyph bci_shift_contour + 1
 
-/* 52 */
+/* 54 */
 #define bci_ip_outer_align_point bci_shift_subglyph + 1
 #define bci_ip_on_align_points bci_ip_outer_align_point + 1
 #define bci_ip_between_align_point bci_ip_on_align_points + 1
 #define bci_ip_between_align_points bci_ip_between_align_point + 1
 
-/* 56 */
+/* 58 */
 #define bci_adjust_common bci_ip_between_align_points + 1
 #define bci_stem_common bci_adjust_common + 1
 #define bci_serif_common bci_stem_common + 1
@@ -408,12 +431,12 @@
 #define bci_serif_link1_common bci_serif_anchor_common + 1
 #define bci_serif_link2_common bci_serif_link1_common + 1
 
-/* 62 */
+/* 64 */
 #define bci_lower_bound bci_serif_link2_common + 1
 #define bci_upper_bound bci_lower_bound + 1
 #define bci_upper_lower_bound bci_upper_bound + 1
 
-/* 65 */
+/* 67 */
 #define bci_adjust_bound bci_upper_lower_bound + 1
 #define bci_stem_bound bci_adjust_bound + 1
 #define bci_link bci_stem_bound + 1
@@ -424,23 +447,23 @@
 /* the order of the `bci_action_*' entries must correspond */
 /* to the order of the TA_Action enumeration entries (in `tahints.h') */
 
-/* 71 */
+/* 73 */
 #define bci_action_ip_before bci_stem + 1
 #define bci_action_ip_after bci_action_ip_before + 1
 #define bci_action_ip_on bci_action_ip_after + 1
 #define bci_action_ip_between bci_action_ip_on + 1
 
-/* 75 */
+/* 77 */
 #define bci_action_blue bci_action_ip_between + 1
 #define bci_action_blue_anchor bci_action_blue + 1
 
-/* 77 */
+/* 79 */
 #define bci_action_anchor bci_action_blue_anchor + 1
 #define bci_action_anchor_serif bci_action_anchor + 1
 #define bci_action_anchor_round bci_action_anchor_serif + 1
 #define bci_action_anchor_round_serif bci_action_anchor_round + 1
 
-/* 81 */
+/* 83 */
 #define bci_action_adjust bci_action_anchor_round_serif + 1
 #define bci_action_adjust_serif bci_action_adjust + 1
 #define bci_action_adjust_round bci_action_adjust_serif + 1
@@ -454,13 +477,13 @@
 #define bci_action_adjust_down_bound_round bci_action_adjust_down_bound_serif + 1
 #define bci_action_adjust_down_bound_round_serif bci_action_adjust_down_bound_round + 1
 
-/* 93 */
+/* 95 */
 #define bci_action_link bci_action_adjust_down_bound_round_serif + 1
 #define bci_action_link_serif bci_action_link + 1
 #define bci_action_link_round bci_action_link_serif + 1
 #define bci_action_link_round_serif bci_action_link_round + 1
 
-/* 97 */
+/* 99 */
 #define bci_action_stem bci_action_link_round_serif + 1
 #define bci_action_stem_serif bci_action_stem + 1
 #define bci_action_stem_round bci_action_stem_serif + 1
@@ -474,7 +497,7 @@
 #define bci_action_stem_down_bound_round bci_action_stem_down_bound_serif + 1
 #define bci_action_stem_down_bound_round_serif bci_action_stem_down_bound_round + 1
 
-/* 109 */
+/* 111 */
 #define bci_action_serif bci_action_stem_down_bound_round_serif + 1
 #define bci_action_serif_lower_bound bci_action_serif + 1
 #define bci_action_serif_upper_bound bci_action_serif_lower_bound + 1
@@ -483,7 +506,7 @@
 #define bci_action_serif_down_upper_bound bci_action_serif_down_lower_bound + 1
 #define bci_action_serif_down_upper_lower_bound bci_action_serif_down_upper_bound + 1
 
-/* 116 */
+/* 118 */
 #define bci_action_serif_anchor bci_action_serif_down_upper_lower_bound + 1
 #define bci_action_serif_anchor_lower_bound bci_action_serif_anchor + 1
 #define bci_action_serif_anchor_upper_bound bci_action_serif_anchor_lower_bound + 1
@@ -492,7 +515,7 @@
 #define bci_action_serif_anchor_down_upper_bound bci_action_serif_anchor_down_lower_bound + 1
 #define bci_action_serif_anchor_down_upper_lower_bound bci_action_serif_anchor_down_upper_bound + 1
 
-/* 123 */
+/* 125 */
 #define bci_action_serif_link1 bci_action_serif_anchor_down_upper_lower_bound + 1
 #define bci_action_serif_link1_lower_bound bci_action_serif_link1 + 1
 #define bci_action_serif_link1_upper_bound bci_action_serif_link1_lower_bound + 1
@@ -501,7 +524,7 @@
 #define bci_action_serif_link1_down_upper_bound bci_action_serif_link1_down_lower_bound + 1
 #define bci_action_serif_link1_down_upper_lower_bound bci_action_serif_link1_down_upper_bound + 1
 
-/* 130 */
+/* 132 */
 #define bci_action_serif_link2 bci_action_serif_link1_down_upper_lower_bound + 1
 #define bci_action_serif_link2_lower_bound bci_action_serif_link2 + 1
 #define bci_action_serif_link2_upper_bound bci_action_serif_link2_lower_bound + 1
@@ -510,10 +533,10 @@
 #define bci_action_serif_link2_down_upper_bound bci_action_serif_link2_down_lower_bound + 1
 #define bci_action_serif_link2_down_upper_lower_bound bci_action_serif_link2_down_upper_bound + 1
 
-/* 137 */
+/* 139 */
 #define bci_hint_glyph bci_action_serif_link2_down_upper_lower_bound + 1
 
-/* 138 */
+/* 140 */
 #define bci_freetype_enable_deltas bci_hint_glyph + 1
 
 #define NUM_FDEFS bci_freetype_enable_deltas + 1 /* must be last */
@@ -528,8 +551,8 @@
 #define cvtl_temp 0 /* used for creating twilight points */
 #define cvtl_funits_to_pixels cvtl_temp + 1
 #define cvtl_is_subglyph cvtl_funits_to_pixels + 1
-#define cvtl_use_strong_functions cvtl_is_subglyph + 1
-#define cvtl_is_element cvtl_use_strong_functions + 1
+#define cvtl_stem_width_mode cvtl_is_subglyph + 1
+#define cvtl_is_element cvtl_stem_width_mode + 1
 #define cvtl_do_iup_y cvtl_is_element + 1
 #define cvtl_ignore_std_width cvtl_do_iup_y + 1
 
