@@ -1,7 +1,7 @@
 /* tahints.h */
 
 /*
- * Copyright (C) 2011-2016 by Werner Lemberg.
+ * Copyright (C) 2011-2018 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -257,6 +257,7 @@ typedef struct TA_SegmentRec_
   FT_Byte flags; /* edge/segment flags for this segment */
   FT_Char dir; /* segment direction */
   FT_Short pos; /* position of segment */
+  FT_Short delta; /* deviation from segment position */
   FT_Short min_coord; /* minimum coordinate of segment */
   FT_Short max_coord; /* maximum coordinate of segment */
   FT_Short height; /* the hinted segment height */
@@ -266,7 +267,6 @@ typedef struct TA_SegmentRec_
 
   TA_Segment link; /* (stem) link segment */
   TA_Segment serif; /* primary segment for serifs */
-  FT_Pos num_linked; /* number of linked segments */
   FT_Pos score; /* used during stem matching */
   FT_Pos len; /* used during stem matching */
 
@@ -291,7 +291,6 @@ typedef struct TA_EdgeRec_
 
   TA_Edge link; /* link edge */
   TA_Edge serif; /* primary edge for serifs */
-  FT_Short num_linked; /* number of linked edges */
   FT_Int score; /* used during stem matching */
 
   TA_Segment first; /* first segment in edge */
