@@ -1,7 +1,7 @@
 /* ttfautohint.c */
 
 /*
- * Copyright (C) 2011-2017 by Werner Lemberg.
+ * Copyright (C) 2011-2018 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -659,6 +659,17 @@ No_check:
       if (error)
         goto Err;
 
+      /* we need the total number of points */
+      /* for point delta instructions of composite glyphs; */
+      /* we need composite point number sums */
+      /* for adjustments due to the `.ttfautohint' glyph */
+      if (sfnt->max_components)
+      {
+        error = TA_sfnt_compute_composite_pointsums(sfnt, font);
+        if (error)
+          goto Err;
+      }
+
       /* this call creates a `globals' object... */
       error = TA_sfnt_handle_coverage(sfnt, font);
       if (error)
